<?php

// Exit if accessed directly
if ( ! defined('ABSPATH') ) die( 'Access Denied.' );

/**
 * Adds custom user roles
 *
 * @since 1.52
 */
function socrates_add_custom_roles() {

	// make sure we didn't already add the roles
	if ( ! get_option( 'soc_custom_roles_added', false ) && function_exists( 'get_editable_roles' ) ) {

		// add roles
		add_role( 'soc_level_1', esc_html__( 'Level 1', 'socrates-plugin' ), array( 'read' => true ) );
		add_role( 'soc_level_2', esc_html__( 'Level 2', 'socrates-plugin' ), array( 'read' => true ) );
		add_role( 'soc_level_3', esc_html__( 'Level 3', 'socrates-plugin' ), array( 'read' => true ) );
		add_role( 'soc_level_4', esc_html__( 'Level 4', 'socrates-plugin' ), array( 'read' => true ) );

		// create random IDs for user roles
		$role_ids = array();
		foreach ( get_editable_roles() as $role_name => $role_info ) {
			$role_ids[$role_name] = str_shuffle( uniqid() );
		}
		update_option( 'soc_user_role_ids', $role_ids );

		// make sure we don't run the code again 
		update_option( 'soc_custom_roles_added', 'true' );

	}

} add_action( 'admin_init', 'socrates_add_custom_roles' );

/**
 * Updates missing unique IDs for roles
 *
 * @since 1.52
 */
function socrates_fix_missing_role_id() {

	// only if we already did it once
	if ( get_option( 'soc_custom_roles_added', false ) && function_exists( 'get_editable_roles' ) ) {
	
		// create random IDs for user roles
		$role_ids = get_option( 'soc_user_role_ids', array() );
		foreach ( get_editable_roles() as $role_name => $role_info ) {
			if ( empty( $role_ids[$role_name] ) ) {
				$role_ids[$role_name] = str_shuffle( uniqid() );
			}
		}
		update_option( 'soc_user_role_ids', $role_ids );

	}

}
global $wpdb;
if ( ! empty( $wpdb ) && function_exists( 'get_current_blog_id' ) ) {
	$site_id = get_current_blog_id();		
	$role_key = $wpdb->get_blog_prefix( $site_id ) . 'user_roles';
	add_action( 'update_option_' . $role_key, 'socrates_fix_missing_role_id' );
}

/**
 * Hooks actions based on $_POST superglobal
 *
 * @since 1.0
 */
function socrates_plugin_post_actions() {
	if ( isset( $_POST['socrates_plugin_action'] ) ) {
		do_action( 'socrates_plugin_' . $_POST['socrates_plugin_action'], $_POST );
	}
} add_action( 'init', 'socrates_plugin_post_actions' );

/**
 * Register admin page
 *
 * @since 1.0
 */
function socrates_plugin_admin_page_register() {

	// add the page
	add_menu_page( 
		esc_html__( 'Socrates Toolkit', 'socrates-plugin' ), 
		esc_html__( 'Socrates', 'socrates-plugin' ), 
		'manage_options',
		'socrates_plugin', 
		'socrates_plugin_admin_page_output', 
		SOC_URL . '/assets/img/socrates-icon.png'
	);

	
	// add submenu - monetize
	add_submenu_page( 
		'socrates_plugin', 
		esc_html__( 'Socrates Monetization', 'socrates-plugin' ),
		esc_html__( 'Monetization', 'socrates-plugin' ),
		'manage_options', 
		'socrates_plugin&tab=monetize', 
		'socrates_plugin_admin_page_output'
	);

	// add submenu - custom code
	add_submenu_page( 
		'socrates_plugin', 
		esc_html__( 'Socrates Monetization', 'socrates-plugin' ),
		esc_html__( 'CSS and Hooks', 'socrates-plugin' ),
		'manage_options', 
		'socrates_plugin&tab=custom_code', 
		'socrates_plugin_admin_page_output'
	);

	// add submenu - Functions
	add_submenu_page( 
		'socrates_plugin', 
		esc_html__( 'Socrates Monetization', 'socrates-plugin' ),
		esc_html__( 'Functions', 'socrates-plugin' ),
		'manage_options', 
		'socrates_plugin&tab=functions', 
		'socrates_plugin_admin_page_output'
	);

	// add submenu - Membership
	add_submenu_page( 
		'socrates_plugin', 
		esc_html__( 'Socrates Monetization', 'socrates-plugin' ),
		esc_html__( 'Membership', 'socrates-plugin' ),
		'manage_options', 
		'socrates_plugin&tab=membership', 
		'socrates_plugin_admin_page_output'
	);

	// add submenu - custom code
	add_submenu_page( 
		'socrates_plugin', 
		esc_html__( 'Socrates Monetization', 'socrates-plugin' ),
		esc_html__( 'Resources', 'socrates-plugin' ),
		'manage_options', 
		'socrates_plugin&tab=resources', 
		'socrates_plugin_admin_page_output'
	);

} add_action( 'admin_menu', 'socrates_plugin_admin_page_register' );

/**
 * Output admin page
 *
 * @since 1.0
 */
function socrates_plugin_admin_page_output() {

	// Stop if the user does not have permission to access
	if ( ! current_user_can( 'manage_options' ) ) wp_die( __( 'You do not have sufficient permissions to access this page.' ) );

	// Active tab
	$active_tab = isset( $_GET['tab'] ) ? $_GET['tab'] : 'welcome';

	?>
	<div class="wrap">

		<h2><?php esc_html_e( 'Socrates Toolkit', 'socrates-plugin' ); ?></h2>

		<h2 class="nav-tab-wrapper">
			<a href="<?php echo add_query_arg( array( 'tab' => 'welcome' ) ); ?>" class="nav-tab <?php if ( $active_tab == 'welcome' ) echo 'nav-tab-active'; ?>"><i class="fa fa-home"></i> <?php esc_html_e( 'Welcome', 'socrates-plugin' ); ?></a>
			
			<a href="<?php echo add_query_arg( array( 'tab' => 'monetize' ) ); ?>" class="nav-tab <?php if ( $active_tab == 'monetize' ) echo 'nav-tab-active'; ?>"><i class="fa fa-money"></i> <?php esc_html_e( 'Monetization', 'socrates-plugin' ); ?></a>
			<a href="<?php echo add_query_arg( array( 'tab' => 'custom_code' ) ); ?>" class="nav-tab <?php if ( $active_tab == 'custom_code' ) echo 'nav-tab-active'; ?>"><i class="fa fa-css3"></i> <?php esc_html_e( 'CSS and Hooks', 'socrates-plugin' ); ?></a>
			<a href="<?php echo add_query_arg( array( 'tab' => 'functions' ) ); ?>" class="nav-tab <?php if ( $active_tab == 'functions' ) echo 'nav-tab-active'; ?>"><i class="fa fa-wrench"></i> <?php esc_html_e( 'Functions', 'socrates-plugin' ); ?></a>
			<a href="<?php echo add_query_arg( array( 'tab' => 'membership' ) ); ?>" class="nav-tab <?php if ( $active_tab == 'membership' ) echo 'nav-tab-active'; ?>"><i class="fa fa-users"></i> <?php esc_html_e( 'Membership', 'socrates-plugin' ); ?></a>
			<a href="<?php echo add_query_arg( array( 'tab' => 'resources' ) ); ?>" class="nav-tab <?php if ( $active_tab == 'resources' ) echo 'nav-tab-active'; ?>"><i class="fa fa-cubes"></i> <?php esc_html_e( 'Resources', 'socrates-plugin' ); ?></a>
		</h2><!-- .nav-tab-wrapper -->

		<div class="metabox-holder" style="max-width:970px">
			<?php do_action( 'socrates_plugin_admin_tab_' . $active_tab ); ?>
		</div><!-- .metabox-holder -->

	</div><!-- .wrap -->
	<?php

}
/**
 * Welcome tab - Display
 *
 * @since 1.0
 */
function socrates_plugin_admin_tab_welcome_diplay() {

	// Stop if the user does not have permission to access
	if ( ! current_user_can( 'manage_options' ) ) return;

	?>
	<div class="postbox">

		<h2 class="hndle"><span><?php esc_html_e( 'Welcome to the Socrates Toolkit', 'socrates-plugin' ); ?></span></h2>

		<div class="inside">

			<p>The Socrates Toolkit Plugin replaces monetization and shortcode functions that were built into the original Socrates theme.</p>
			<p>Just click on the TABS and follow the prompts to set up your ads, insert custom codes and more.</p>
			<p>On your post/page editor you'll see the Socrates Icon which opens all the shortcodes available.</p>
			
			<p>Learn more in our <a rel="noopener" target="_blank" href="https://customers.socratestheme.com/documentation/">Customer Portal</a> or on our <a rel="noopener" target="_blank" href="https://www.youtube.com/c/SocratesTheme">YouTube Channel</a>.</p>
			
			<p><em>The Toolkit can be used with other themes as well, though we recommend you review pages using the codes if you switch. The styling could be slightly off with some shortcodes.</em></p>

		</div><!-- .inside -->

	</div><!-- .postbox -->
	<?php

} add_action( 'socrates_plugin_admin_tab_welcome', 'socrates_plugin_admin_tab_welcome_diplay' );

/**
 * Functions - Display
 *
 * @since 1.0
 */
function socrates_plugin_admin_tab_functions_diplay() {

	// Stop if the user does not have permission to access
	if ( ! current_user_can( 'manage_options' ) ) return;

	// defaults
	$disable_emoji = '';
	$disable_version = '';
	$disable_front_js = '';
	$disable_font_awesome = '';
	$disable_gutenberg_css = '';

	// Get current values
	$options = get_option( 'soc_custom_codes' );

	// Disable emoji
	if ( is_array( $options ) && isset( $options['soc_function_disable_emoji'] ) ) {
		$disable_emoji = $options['soc_function_disable_emoji'];
	}

	// Disable version
	if ( is_array( $options ) && isset( $options['soc_function_disable_version'] ) ) {
		$disable_version = $options['soc_function_disable_version'];
	}

	// Disable front.js
	if ( is_array( $options ) && isset( $options['soc_function_disable_front_js'] ) ) {
		$disable_front_js = $options['soc_function_disable_front_js'];
	}

	// Disable font awesome
	if ( is_array( $options ) && isset( $options['soc_function_disable_font_awesome'] ) ) {
		$disable_font_awesome = $options['soc_function_disable_font_awesome'];
	}

	// Disable Gutenberg CSS
	if ( is_array( $options ) && isset( $options['soc_function_disable_gutenberg_css'] ) ) {
		$disable_gutenberg_css = $options['soc_function_disable_gutenberg_css'];
	}

	?>
	<div class="postbox">

		<h2 class="hndle"><span><?php esc_html_e( 'Functions', 'socrates-plugin' ); ?></span></h2>
		

		<div class="inside">
			<p>Here are some simple functions that will help improve or speed up your theme.</p> 
			<p>1. Wordpress adds Emoji support coding in every page, but it's rarely used. You can remove the code here.<br/>
			2. A lot of people like to remove Version numbers from their source code. This lets you do it in one click.<br/>
3. If you're not using our Toggles, Tabs, Timers, Progress Bars, Counters, Accordion Menus, you can disable the Front.js file.<br/>
4. If you're not using Font Awesome Icons at all, you can disable that library from being called here. (Socrates/Speaker Theme Only).<br/>
5. If you're not using Gutenberg you can disable the CSS file from being enqueued here.</p> 
<p>IMPORTANT: Always make sure your site looks and works properly if checking these advanced options.  If you don't understand what they mean, you don't need to use disable them.</p>

<p><a rel="noopener" target="_blank" href="https://imcodex.com/page-speed-checklist/">See My PageSpeed Checklist Here</a></p>
			<form method="post" action="<?php echo admin_url( 'admin.php?page=socrates_plugin&tab=functions' ); ?>">
				
				<p>
					<input name="soc_function_disable_emoji" id="soc_function_disable_emoji" type="checkbox" <?php checked( 'on', $disable_emoji, true ); ?> />
					<label for="soc_function_disable_emoji"><strong><?php esc_html_e( '1. Disable Emoji scripts and styles', 'socrates-plugin' ); ?></strong></label>
				</p>

				<p>
					<input name="soc_function_disable_version" id="soc_function_disable_version" type="checkbox" <?php checked( 'on', $disable_version, true ); ?> />
					<label for="soc_function_disable_version"><strong><?php esc_html_e( '2. Remove the WordPress Version Info for Security', 'socrates-plugin' ); ?></strong></label>
				</p>

				<p>
					<input name="soc_function_disable_front_js" id="soc_function_disable_front_js" type="checkbox" <?php checked( 'on', $disable_front_js, true ); ?> />
					<label for="soc_function_disable_front_js"><strong><?php esc_html_e( '3. Disable loading of front.js plugin file', 'socrates-plugin' ); ?></strong></label>
				</p>

				<p>
					<input name="soc_function_disable_font_awesome" id="soc_function_disable_font_awesome" type="checkbox" <?php checked( 'on', $disable_font_awesome, true ); ?> />
					<label for="soc_function_disable_font_awesome"><strong><?php esc_html_e( '4. Disable loading of Font Awesome plugin files', 'socrates-plugin' ); ?></strong></label>
				</p>

				<p>
					<input name="soc_function_disable_gutenberg_css" id="soc_function_disable_gutenberg_css" type="checkbox" <?php checked( 'on', $disable_gutenberg_css, true ); ?> />
					<label for="soc_function_disable_gutenberg_css"><strong><?php esc_html_e( '5. Disable loading of Gutenberg Library CSS file', 'socrates-plugin' ); ?></strong></label>
				</p>

				<p>
					<input type="hidden" name="socrates_plugin_action" value="functions_save" />
					<?php wp_nonce_field( 'socrates_plugin_functions_save_nonce', 'socrates_plugin_functions_save_nonce' ); ?>
					<?php submit_button( esc_html__( 'Save', 'socrates-plugin' ), 'secondary', 'submit', false ); ?>
				</p>

			</form>

		</div><!-- .inside -->

	</div><!-- .postbox -->
	<?php

} add_action( 'socrates_plugin_admin_tab_functions', 'socrates_plugin_admin_tab_functions_diplay' );

/**
 * Functions - Save
 *
 * @since 1.0
 */
function socrates_plugin_admin_tab_functions_save() {

	// Check the nonce
	if( ! wp_verify_nonce( $_POST['socrates_plugin_functions_save_nonce'], 'socrates_plugin_functions_save_nonce' ) ) {
		return;
	}

	// Stop if the user does not have permission to access
	if( ! current_user_can( 'manage_options' ) ) {
		return;
	}

	// Disable emoji
	if ( isset( $_POST['soc_function_disable_emoji'] ) ) {
		$disable_emoji = 'on';
	} else {
		$disable_emoji = 'off';
	}

	// Disable version
	if ( isset( $_POST['soc_function_disable_version'] ) ) {
		$disable_version = 'on';
	} else {
		$disable_version = 'off';
	}

	// Disable front.js
	if ( isset( $_POST['soc_function_disable_front_js'] ) ) {
		$disable_front_js = 'on';
	} else {
		$disable_front_js = 'off';
	}	

	// Disable Font Awesome
	if ( isset( $_POST['soc_function_disable_font_awesome'] ) ) {
		$disable_font_awesome = 'on';
	} else {
		$disable_font_awesome = 'off';
	}

	// Disable Gutenberg CSS
	if ( isset( $_POST['soc_function_disable_gutenberg_css'] ) ) {
		$disable_gutenberg_css = 'on';
	} else {
		$disable_gutenberg_css = 'off';
	}

	// Options combined
	$options_new = array(
		'soc_function_disable_emoji' => stripslashes( $disable_emoji ),
		'soc_function_disable_version' => stripslashes( $disable_version ),
		'soc_function_disable_front_js' => stripslashes( $disable_front_js ),
		'soc_function_disable_font_awesome' => stripslashes( $disable_font_awesome ),
		'soc_function_disable_gutenberg_css' => stripslashes( $disable_gutenberg_css ),
	);

	// Current options
	$options_current = get_option( 'soc_custom_codes' );

	// If values exists, combine
	if ( $options_current ) {
		$options_final = array_merge( $options_current, $options_new );

	// If not, just include current
	} else {
		$options_final = $options_new;
	}

	// Save
	update_option( 'soc_custom_codes', $options_final );

} add_action( 'socrates_plugin_functions_save', 'socrates_plugin_admin_tab_functions_save' );

/**
 * Monetize - Display
 *
 * @since 1.0
 */
function socrates_plugin_admin_tab_monetize_diplay() {

	// Stop if the user does not have permission to access
	if ( ! current_user_can( 'manage_options' ) ) return;

	// defaults
	$top_ad_content = '';
	$top_ad_align = '';
	$top_ad_display_on = '';
	$bottom_ad_content = '';
	$bottom_ad_align = '';
	$bottom_ad_display_on = '';
	$affiliate_url = '';

	// Get current values
	$options = get_option( 'soc_custom_codes' );

	// Top ad content
	if ( is_array( $options ) && isset( $options['soc_post_ad_content_top'] ) ) {
		$top_ad_content = $options['soc_post_ad_content_top'];
	}

	// Top ad position
	if ( is_array( $options ) && isset( $options['soc_post_ad_top_pos'] ) ) {
		$top_ad_align = $options['soc_post_ad_top_pos'];
	}

	// Top ad display on
	if ( is_array( $options ) && isset( $options['soc_post_ad_top_display'] ) ) {
		$top_ad_display_on = $options['soc_post_ad_top_display'];
	}

	// Bottom ad content
	if ( is_array( $options ) && isset( $options['soc_post_ad_content_bottom'] ) ) {
		$bottom_ad_content = $options['soc_post_ad_content_bottom'];
	}

	// Bottom ad position
	if ( is_array( $options ) && isset( $options['soc_post_ad_bot'] ) ) {
		$bottom_ad_align = $options['soc_post_ad_bot'];
	}

	// Bottom ad display on
	if ( is_array( $options ) && isset( $options['soc_post_ad_bot_display'] ) ) {
		$bottom_ad_display_on = $options['soc_post_ad_bot_display'];
	}

	// Affiliate URL
	if ( is_array( $options ) && isset( $options['soc_affiliate_link'] ) ) {
		$affiliate_url = $options['soc_affiliate_link'];
	}

	?>
	<div class="postbox">

		<h2 class="hndle"><span><?php esc_html_e( 'Monetization', 'socrates-plugin' ); ?></span></h2>

		<div class="inside">

			<form method="post" action="<?php echo admin_url( 'admin.php?page=socrates_plugin&tab=monetize' ); ?>">
				
				<h3><?php esc_html_e( 'In Post Ad Top', 'socrates-plugin' ); ?></h3>
				<span class="description"><?php esc_html_e( 'This ad will appear at the beginning of the post content with text flowing around it.', 'socrates-plugin' ); ?></span>
				<p><textarea name="soc_post_ad_content_top" rows="5" class="large-text"><?php echo $top_ad_content; ?></textarea></p>
				
				<table class="form-table">
					<tbody>
						<tr>
							<th><?php esc_html_e( 'Alignment', 'socrates-plugin' ); ?></th>
							<td>
								<select name="soc_post_ad_top_pos">
									<option value="none" <?php if ( $top_ad_align == 'none' ) echo 'selected'; ?>><?php esc_html_e( 'None', 'socrates-plugin' ); ?></option>
									<option value="left" <?php if ( $top_ad_align == 'left' ) echo 'selected'; ?>><?php esc_html_e( 'Left', 'socrates-plugin' ); ?></option>
									<option value="right" <?php if ( $top_ad_align == 'right' ) echo 'selected'; ?>><?php esc_html_e( 'Right', 'socrates-plugin' ); ?></option>
								</select>
							</td>
						</tr>
						<tr>
							<th><?php esc_html_e( 'Display On', 'socrates-plugin' ); ?></th>
							<td>
								<select name="soc_post_ad_top_display">
									<option value="all" <?php if ( $top_ad_display_on == 'all' ) echo 'selected'; ?>><?php esc_html_e( 'Posts and Pages', 'socrates-plugin' ); ?></option>
									<option value="post" <?php if ( $top_ad_display_on == 'post' ) echo 'selected'; ?>><?php esc_html_e( 'Posts', 'socrates-plugin' ); ?></option>
									<option value="page" <?php if ( $top_ad_display_on == 'page' ) echo 'selected'; ?>><?php esc_html_e( 'Pages', 'socrates-plugin' ); ?></option>
									<option value="hide" <?php if ( $top_ad_display_on == 'hide' ) echo 'selected'; ?>><?php esc_html_e( 'Do not display', 'socrates-plugin' ); ?></option>
								</select>
							</td>
						</tr>
					</tbody>
				</table>

				<hr />

				<h3><?php esc_html_e( 'In Post Ad Bottom', 'socrates-plugin' ); ?></h3>
				<span class="description"><?php esc_html_e( 'This ad location at the end of the post content. You can choose to show on post, pages, or both. Note: It will also show on "full content" loops if posts are selected. You can use Adsense Link Units, Clickbank hoplinks, optin boxes or other affiliate program code.  There is also a custom bottom content hook on our custom hooks tab that ONLY shows on single posts below the loop.', 'socrates-plugin' ); ?></span>
				<p><textarea name="soc_post_ad_content_bottom" rows="5" class="large-text"><?php echo $bottom_ad_content; ?></textarea></p>
				
				<table class="form-table">
					<tbody>
						<tr>
							<th><?php esc_html_e( 'Alignment', 'socrates-plugin' ); ?></th>
							<td>
								<select name="soc_post_ad_bot">
									<option value="none" <?php if ( $bottom_ad_align == 'none' ) echo 'selected'; ?>><?php esc_html_e( 'None', 'socrates-plugin' ); ?></option>
									<option value="left" <?php if ( $bottom_ad_align == 'left' ) echo 'selected'; ?>><?php esc_html_e( 'Left', 'socrates-plugin' ); ?></option>
									<option value="right" <?php if ( $bottom_ad_align == 'right' ) echo 'selected'; ?>><?php esc_html_e( 'Right', 'socrates-plugin' ); ?></option>
								</select>
							</td>
						</tr>
						<tr>
							<th><?php esc_html_e( 'Display On', 'socrates-plugin' ); ?></th>
							<td>
								<select name="soc_post_ad_bot_display">
									<option value="all" <?php if ( $bottom_ad_display_on == 'all' ) echo 'selected'; ?>><?php esc_html_e( 'Posts and Pages', 'socrates-plugin' ); ?></option>
									<option value="post" <?php if ( $bottom_ad_display_on == 'post' ) echo 'selected'; ?>><?php esc_html_e( 'Posts', 'socrates-plugin' ); ?></option>
									<option value="page" <?php if ( $bottom_ad_display_on == 'page' ) echo 'selected'; ?>><?php esc_html_e( 'Pages', 'socrates-plugin' ); ?></option>
									<option value="hide" <?php if ( $bottom_ad_display_on == 'hide' ) echo 'selected'; ?>><?php esc_html_e( 'Do not display', 'socrates-plugin' ); ?></option>
								</select>
							</td>
						</tr>
					</tbody>
				</table>

				<hr />

				<h3><?php esc_html_e( 'Our Affiliate Program', 'socrates-plugin' ); ?></h3>
				<span class="description"><?php _e( 'Get details about our affiliate program at <a rel="noopener" target="_blank" href="https://www.socratestheme.com/affiliates/">here</a>. You can then enter your affiliate link in our customizer under Copyright and Affiliate info and earn you 50% per sale.', 'socrates-plugin' ); ?></span>
				

				<p>
					<input type="hidden" name="socrates_plugin_action" value="monetize_save" />
					<?php wp_nonce_field( 'socrates_plugin_monetize_save_nonce', 'socrates_plugin_monetize_save_nonce' ); ?>
					<?php submit_button( esc_html__( 'Save', 'socrates-plugin' ), 'secondary', 'submit', false ); ?>
				</p>

			</form>

		</div><!-- .inside -->

	</div><!-- .postbox -->
	<?php

} add_action( 'socrates_plugin_admin_tab_monetize', 'socrates_plugin_admin_tab_monetize_diplay' );

/**
 * Monetize - Save
 *
 * @since 1.0
 */
function socrates_plugin_admin_tab_monetize_save() {

	// Check the nonce
	if( ! wp_verify_nonce( $_POST['socrates_plugin_monetize_save_nonce'], 'socrates_plugin_monetize_save_nonce' ) ) {
		return;
	}

	// Stop if the user does not have permission to access
	if( ! current_user_can( 'manage_options' ) ) {
		return;
	}

	// Top ad content
	$top_ad_content = '';
	if( ! empty( $_POST['soc_post_ad_content_top'] ) ) {
		$top_ad_content = $_POST['soc_post_ad_content_top'];
	}

	// Top ad position
	$top_ad_align = '';
	if( ! empty( $_POST['soc_post_ad_top_pos'] ) ) {
		$top_ad_align = $_POST['soc_post_ad_top_pos'];
	}

	// Top ad display
	$top_ad_display_on = '';
	if( ! empty( $_POST['soc_post_ad_top_display'] ) ) {
		$top_ad_display_on = $_POST['soc_post_ad_top_display'];
	}

	// Bottom ad content
	$bottom_ad_content= '';
	if( ! empty( $_POST['soc_post_ad_content_bottom'] ) ) {
		$bottom_ad_content = $_POST['soc_post_ad_content_bottom'];
	}

	// Bottom ad position
	$bottom_ad_align = '';
	if( ! empty( $_POST['soc_post_ad_bot'] ) ) {
		$bottom_ad_align = $_POST['soc_post_ad_bot'];
	}

	// Bottom ad display
	$bottom_ad_display_on = '';
	if( ! empty( $_POST['soc_post_ad_bot_display'] ) ) {
		$bottom_ad_display_on = $_POST['soc_post_ad_bot_display'];
	}

	// Affiliate URL
	$affiliate_url = '';
	if ( ! empty( $_POST['soc_affiliate_link'] ) ) {
		$affiliate_url = $_POST['soc_affiliate_link'];
	}

	// Options combined
	$options_new = array(
		'soc_post_ad_content_top' => stripslashes( $top_ad_content ),
		'soc_post_ad_top_pos' => stripslashes( $top_ad_align ),
		'soc_post_ad_top_display' => stripslashes( $top_ad_display_on ),
		'soc_post_ad_content_bottom' => stripslashes( $bottom_ad_content ),
		'soc_post_ad_bot' => stripslashes( $bottom_ad_align ),
		'soc_post_ad_bot_display' => stripslashes( $bottom_ad_display_on ),
		'soc_affiliate_link' => stripslashes( $affiliate_url ),
	);

	// Current options
	$options_current = get_option( 'soc_custom_codes' );

	// If values exists, combine
	if ( $options_current ) {
		$options_final = array_merge( $options_current, $options_new );

	// If not, just include current
	} else {
		$options_final = $options_new;
	}

	// Save
	update_option( 'soc_custom_codes', $options_final );

} add_action( 'socrates_plugin_monetize_save', 'socrates_plugin_admin_tab_monetize_save' );

/**
 * Code tab - Display
 *
 * @since 1.0
 */
function socrates_plugin_admin_tab_custom_code_diplay() {

	// Stop if the user does not have permission to access
	if ( ! current_user_can( 'manage_options' ) ) return;

	// defaults
	$option_css = '';
	$option_header = '';
	$option_footer = '';
	$option_after_post = '';

	// Get current values
	$options = get_option( 'soc_custom_codes' );

	// CSS
	if ( is_array( $options ) && isset( $options['soc_custom_css'] ) ) {
		$option_css = $options['soc_custom_css'];
	}

	// Header
	if ( is_array( $options ) && isset( $options['soc_custom_header_code'] ) ) {
		$option_header = $options['soc_custom_header_code'];
	}

	// Footer
	if ( is_array( $options ) && isset( $options['soc_custom_footer_code'] ) ) {
		$option_footer = $options['soc_custom_footer_code'];
	}

	// After post
	if ( is_array( $options ) && isset( $options['soc_custom_after_post_code'] ) ) {
		$option_after_post = $options['soc_custom_after_post_code'];
	}

	?>
	<div class="postbox">

		<h2 class="hndle"><span><?php esc_html_e( 'Custom CSS and Hooks', 'socrates-plugin' ); ?></span></h2>

		<div class="inside">

			<p>Use these fields to insert analytics or pixel codes, custom css and more. </p>
			<p>The New "Below Post Code" box lets you add html or shortcodes at bottom of every single post. It is similar to "In Post Bottom Unit", but works outside the loop.</p>
			<p>See <a rel="noopener" target="_blank" href="https://customers.socratestheme.com/documentation/">documentation</a> for more in on using for Related Posts.</p>
			<hr/>
			



			<form method="post" action="<?php echo admin_url( 'admin.php?page=socrates_plugin&tab=custom_code' ); ?>">
				
				<h3><?php esc_html_e( 'Custom CSS', 'socrates-plugin' ); ?></h3>
				<span class="description"><?php esc_html_e( 'Insert custom CSS to customize the theme.', 'socrates-plugin' ); ?></span>
				<p><textarea name="soc_custom_css" rows="8" class="large-text"><?php echo $option_css; ?></textarea></p>
				
				<hr>

				<h3><?php esc_html_e( 'Custom Header Code', 'socrates-plugin' ); ?></h3>
				<span class="description"><?php esc_html_e( 'Insert custom code into header right above closing header tag.', 'socrates-plugin' ); ?></span>
				<p><textarea name="soc_custom_header_code" rows="8" class="large-text"><?php echo $option_header; ?></textarea></p>

				<hr>
				
				<h3><?php esc_html_e( 'Custom Footer Code', 'socrates-plugin' ); ?></h3>
				<span class="description"><?php esc_html_e( 'Insert custom code into footer.', 'socrates-plugin' ); ?></span>
				<p><textarea name="soc_custom_footer_code" rows="8" class="large-text"><?php echo $option_footer; ?></textarea></p>

				<hr>
				
				<h3><?php esc_html_e( 'Custom Below Post Code', 'socrates-plugin' ); ?></h3>
				<span class="description"><?php esc_html_e( 'Insert HTML or ShortCodes Only, NO PHP - Appears Below Post Content on Single Posts. Use our Posts Shortcode to show Related Posts.', 'socrates-plugin' ); ?></span>
				<p><a rel="noopener" target="_blank" href="https://customers.socratestheme.com/documentation/">See Documentation</a>. And there's example code you can copy and paste below.</p>
				<p><textarea name="soc_custom_after_post_code" rows="8" class="large-text"><?php echo $option_after_post; ?></textarea></p>
				<p>Example Related Posts code you can copy and paste above.<br/><textarea readonly rows="5" class="large-text">[soc_divider height="1" margin_top="40" margin_bottom="5" color="#eee"]
<span class="relatedposts">You May Also Like These Topics...</span>
[soc_divider height="1" margin_top="5" margin_bottom="20" color="#eee"]
[soc_posts columns="1" num_posts="4" style="1" date_meta="1" related="true" thumbnail_size="thumbnail" excerpt_length="" ] </textarea></p>
			
			
				<input type="hidden" name="socrates_plugin_action" value="custom_code_save" />
				<?php wp_nonce_field( 'socrates_plugin_custom_code_save_nonce', 'socrates_plugin_custom_code_save_nonce' ); ?>
				<?php submit_button( esc_html__( 'Save All Codes', 'socrates-plugin' ), 'secondary', 'submit', false ); ?>

			</form>

		</div><!-- .inside -->

	</div><!-- .postbox -->
	<?php

} add_action( 'socrates_plugin_admin_tab_custom_code', 'socrates_plugin_admin_tab_custom_code_diplay' );

/**
 * Code tab - Save
 *
 * @since 1.0
 */
function socrates_plugin_admin_tab_custom_code_save() {

	// Check the nonce
	if( ! wp_verify_nonce( $_POST['socrates_plugin_custom_code_save_nonce'], 'socrates_plugin_custom_code_save_nonce' ) ) {
		return;
	}

	// Stop if the user does not have permission to access
	if( ! current_user_can( 'manage_options' ) ) {
		return;
	}

	// CSS
	$option_css = '';
	if( ! empty( $_POST['soc_custom_css'] ) ) {
		$option_css = $_POST['soc_custom_css'];
	}

	// Header
	$option_header = '';
	if( ! empty( $_POST['soc_custom_header_code'] ) ) {
		$option_header = $_POST['soc_custom_header_code'];
	}

	// Footer
	$option_footer = '';
	if( ! empty( $_POST['soc_custom_footer_code'] ) ) {
		$option_footer = $_POST['soc_custom_footer_code'];
	}

	// After post
	$option_after_post = '';
	if( ! empty( $_POST['soc_custom_after_post_code'] ) ) {
		$option_after_post = $_POST['soc_custom_after_post_code'];
	}

	// Options combined
	$options_new = array(
		'soc_custom_css' => stripslashes( $option_css ),
		'soc_custom_header_code' => stripslashes( $option_header ),
		'soc_custom_footer_code' => stripslashes( $option_footer ),
		'soc_custom_after_post_code' => stripslashes( $option_after_post ),
	);

	// Current options
	$options_current = get_option( 'soc_custom_codes' );

	// If values exists, combine
	if ( $options_current ) {
		$options_final = array_merge( $options_current, $options_new );

	// If not, just include current
	} else {
		$options_final = $options_new;
	}

	// Save
	update_option( 'soc_custom_codes', $options_final );	

} add_action( 'socrates_plugin_custom_code_save', 'socrates_plugin_admin_tab_custom_code_save' );

/**
 * Resources tab - Display
 *
 * @since 1.0
 */
function socrates_plugin_admin_tab_resources_diplay() {

	// Stop if the user does not have permission to access
	if ( ! current_user_can( 'manage_options' ) ) return;

	?>
	<div class="postbox">

		<h3 class="hndle"><span><?php esc_html_e( 'Resources', 'socrates-plugin' ); ?></span></h3>

		<div class="inside">
		
	
			<p><strong>We'll be expanding this resources section soon with plugin recommendations and links.</strong></p>
			
			<p><a rel="noopener" target="_blank" href="https://customers.socratestheme.com">Our Customer and Support Portal</a></p>
			<p><a rel="noopener" target="_blank" href="https://www.youtube.com/c/SocratesTheme">Our YouTube Channel</a></p>
			<p><a rel="noopener" target="_blank" href="https://facebook.com/socrateswptheme">Our Facebook Page</a></p>
			
			<p><strong>Recommended Optimization Plugins</strong></p>
			
			<p><a rel="noopener" target="_blank" href="https://wordpress.org/plugins/autoptimize/">Autoptimize</a></p>
			
			<p><strong>Recommended Products</strong></p>
			
			<p><a rel="noopener" target="_blank" href="https://socratestheme.com/goto/getsitecontrol.php">Get Site Control</a> - Popups, Live Chat, Promo Boxes and More</p>
			<p><strong><a rel="noopener" target="_blank" href="https://www.siteground.com/go/socrates">SiteGround Hosting</a> - Our Recommended Webhost with Free SSL and Backups.</strong></p>
			<p><a rel="noopener" target="_blank" href="https://imcodex.com">IMCodex</a> - Save Money and Grow Your Business</p>
			<p><a rel="noopener" target="_blank" href="http://www.iontheory.com">Mindset Hacks</a> - Dan's ION Theory</p>
			
				<h2><a rel="noopener" target="_blank" href="https://imcodex.com/im-starter-course/tools-resources/">ALL MY RECOMMENDED PRODUCTS</a></h2>
	

		</div><!-- .inside -->

	</div><!-- .postbox -->
	<?php

} add_action( 'socrates_plugin_admin_tab_resources', 'socrates_plugin_admin_tab_resources_diplay' );

/**
 * Membership - Display
 *
 * @since 1.51
 */
function socrates_plugin_admin_tab_membership_diplay() {

	// Stop if the user does not have permission to access
	if ( ! current_user_can( 'manage_options' ) ) return;

	// defaults
	$enable_email = 'on';
	$enable_first_name = '';
	$enable_last_name = '';
	$enable_hide_toolbar = '';
	$membership_redirect = 'none';
	$redirect_logout = '';

	// Get current values
	$options = get_option( 'soc_custom_codes' );


	// Enable email
	if ( is_array( $options ) && isset( $options['soc_membership_enable_email'] ) ) {
		$enable_email = $options['soc_membership_enable_email'];
	}

	// Enable first name
	if ( is_array( $options ) && isset( $options['soc_membership_enable_first_name'] ) ) {
		$enable_first_name = $options['soc_membership_enable_first_name'];
	}

	// Enable last name
	if ( is_array( $options ) && isset( $options['soc_membership_enable_last_name'] ) ) {
		$enable_last_name = $options['soc_membership_enable_last_name'];
	}

	// Enable hide admin toolbar
	if ( is_array( $options ) && isset( $options['soc_membership_hide_toolbar'] ) ) {
		$enable_hide_toolbar = $options['soc_membership_hide_toolbar'];
	}	

	// Membership redirect
	if ( is_array( $options ) && isset( $options['soc_membership_redirect'] ) ) {
		$membership_redirect = $options['soc_membership_redirect'];
	}

	// Membership redirect
	if ( is_array( $options ) && isset( $options['soc_membership_redirect_logout'] ) ) {
		$redirect_logout = $options['soc_membership_redirect_logout'];
	}

	?>
	<div class="postbox">

		<h2 class="hndle"><span><?php esc_html_e( 'Membership', 'socrates-plugin' ); ?></span></h2>
		

		<div class="inside">
			<p>Socrates Toolkit has basic membership functions that let you register new users, create custom login forms and protect content.</p>
			<p>The biggest feature "we don't have" is customer email notifications. It adds too much complexity and there are plenty of workarounds.</p>
			<p>We've got a full	demo of all the Member functionality with example codes and tutorials at:
			<a  rel="noopener" target="_blank" href="https://wpmembershiptheme.com">WPMembershipTheme.com</a>.
			</p> <p>We kept our membership system simple for a reason. It's for quick basic membership site and download pages. If you need a robust solution there are many membership plugins online.</p>
			
			
			<form method="post" action="<?php echo admin_url( 'admin.php?page=socrates_plugin&tab=membership' ); ?>">
				
				<hr>

				<h3><?php esc_html_e( 'Membership Settings', 'socrates-plugin' ); ?></h3>
				<p>We only have five basic membership options.  You can be sent an email notification of "new signups", but your customers won't
				get an email.  You can include first name and last name on registration form.</p><p>
				You can choose a "Page" to redirect visitors who land on a "Member Only" page. If no page is assigned a short default message
				and login form will display instead.  Just make a "Not A Member" page and add it here.</p><p>You can also add a url to redirect members to upon logout.  The full url is required. If left blank they'll redirect the 
				default WP login page.

				<p>
					<input name="soc_membership_enable_email" id="soc_membership_enable_email" type="checkbox" <?php checked( 'on', $enable_email, true ); ?> />
					<label for="soc_membership_enable_email"><strong><?php esc_html_e( 'Enable Admin New User Notification Email - For You Only', 'socrates-plugin' ); ?></strong></label>
				</p>

				<p>
					<input name="soc_membership_enable_first_name" id="soc_membership_enable_first_name" type="checkbox" <?php checked( 'on', $enable_first_name, true ); ?> />
					<label for="soc_membership_enable_first_name"><strong><?php esc_html_e( 'Include First Name Field on Registration Form', 'socrates-plugin' ); ?></strong></label>
				</p>

				<p>
					<input name="soc_membership_enable_last_name" id="soc_membership_enable_last_name" type="checkbox" <?php checked( 'on', $enable_last_name, true ); ?> />
					<label for="soc_membership_enable_last_name"><strong><?php esc_html_e( 'Include Last Name Field on Registration Form', 'socrates-plugin' ); ?></strong></label>
				</p>

				<p>
					<input name="soc_membership_hide_toolbar" id="soc_membership_hide_toolbar" type="checkbox" <?php checked( 'on', $enable_hide_toolbar, true ); ?> />
					<label for="soc_membership_hide_toolbar"><strong><?php esc_html_e( 'Hide Admin Toolbar to Non-Admins', 'socrates-plugin' ); ?></strong></label>
				</p>

				<label for="soc_membership_redirect"><strong><?php esc_html_e( 'Page to redirect non logged-in users if Member Only option box is checked', 'socrates-plugin' ); ?></strong></label>

				<?php $pages = get_pages(); ?>
				<p>	

					<select name="soc_membership_redirect" id="soc_membership_redirect">
						<option value="none"><?php esc_html_e( 'No redirection', 'socrates-plugin' ); ?></option>
						<?php foreach ( $pages as $page ) : ?>
							<option value="<?php echo $page->ID; ?>" <?php selected( $page->ID, $membership_redirect, true ); ?>><?php echo $page->post_title; ?></option>
						<?php endforeach; ?>
					</select>
				</p>

				<p>
					<label for="soc_membership_redirect_logout"><strong><?php esc_html_e( 'Full URL including http:// to Redirect members on logout - Leave blank for default', 'socrates-plugin' ); ?></strong></label>
				</p>
				<p>
					<input name="soc_membership_redirect_logout" id="soc_membership_redirect_logout" type="text" value="<?php echo $redirect_logout; ?>" />
				</p>

				<p>
					<input type="hidden" name="socrates_plugin_action" value="membership_save" />
					<?php wp_nonce_field( 'socrates_plugin_membership_save_nonce', 'socrates_plugin_membership_save_nonce' ); ?>
					<?php submit_button( esc_html__( 'Save', 'socrates-plugin' ), 'secondary', 'submit', false ); ?>
				</p>

			</form>

		</div><!-- .inside -->

	</div><!-- .postbox -->
	<?php

} add_action( 'socrates_plugin_admin_tab_membership', 'socrates_plugin_admin_tab_membership_diplay' );

/**
 * Membership - Save
 *
 * @since 1.51
 */
function socrates_plugin_admin_tab_membership_save() {

	// Check the nonce
	if( ! wp_verify_nonce( $_POST['socrates_plugin_membership_save_nonce'], 'socrates_plugin_membership_save_nonce' ) ) {
		return;
	}	

	// Stop if the user does not have permission to access
	if( ! current_user_can( 'manage_options' ) ) {
		return;
	}

	// Enable email
	if ( isset( $_POST['soc_membership_enable_email'] ) ) {
		$enable_email = 'on';
	} else {
		$enable_email = 'off';
	}

	// Enable first name
	if ( isset( $_POST['soc_membership_enable_first_name'] ) ) {
		$enable_first_name = 'on';
	} else {
		$enable_first_name = 'off';
	}

	// Enable last name
	if ( isset( $_POST['soc_membership_enable_last_name'] ) ) {
		$enable_last_name = 'on';
	} else {
		$enable_last_name = 'off';
	}

	// Enable hide toolbar
	if ( isset( $_POST['soc_membership_hide_toolbar'] ) ) {
		$enable_hide_toolbar = 'on';
	} else {
		$enable_hide_toolbar = 'off';
	}

	// Redirection
	if ( isset( $_POST['soc_membership_redirect'] ) ) {
		$membership_redirect = $_POST['soc_membership_redirect'];
	} else {
		$membership_redirect = 'none';
	}

	// Redirection on logout
	if ( isset( $_POST['soc_membership_redirect_logout'] ) ) {
		$redirect_logout = $_POST['soc_membership_redirect_logout'];
	} else {
		$redirect_logout = '';
	}

	// Options combined
	$options_new = array(
		'soc_membership_enable_email' => stripslashes( $enable_email ),
		'soc_membership_enable_first_name' => stripslashes( $enable_first_name ),
		'soc_membership_enable_last_name' => stripslashes( $enable_last_name ),
		'soc_membership_hide_toolbar' => stripslashes( $enable_hide_toolbar ),
		'soc_membership_redirect' => stripslashes( $membership_redirect ),
		'soc_membership_redirect_logout' => stripslashes( $redirect_logout ),
	);

	// Current options
	$options_current = get_option( 'soc_custom_codes' );

	// If values exists, combine
	if ( $options_current ) {
		$options_final = array_merge( $options_current, $options_new );

	// If not, just include current
	} else {
		$options_final = $options_new;
	}

	// Save
	update_option( 'soc_custom_codes', $options_final );

} add_action( 'socrates_plugin_membership_save', 'socrates_plugin_admin_tab_membership_save' );