<?php

/**
 * Register meta boxes
 *
 * @since 1.0
 */
function socrates_plugin_register_meta_boxes() {

	// monetize
	add_meta_box( 'socrates-plugin-ad-meta-box', esc_html__( 'Monetize', 'socrates-plugin' ), 'socrates_plugin_ad_meta_box_callback', array( 'post', 'page' ), 'side', 'low' );

	// other
	add_meta_box( 'socrates-plugin-other-meta-box', esc_html__( 'Other Settings', 'socrates-plugin' ), 'socrates_plugin_other_meta_box_callback', array( 'post', 'page' ), 'side', 'low' );

} add_action( 'add_meta_boxes', 'socrates_plugin_register_meta_boxes', 11 );

/**
 * Monetize - Display callback
 *
 * @since 1.0
 */
function socrates_plugin_ad_meta_box_callback( $post ) {

	// nonces for security
	wp_nonce_field( 'socrates_plugin_monetize', 'socrates_plugin_monetize_nonce' );

	// current value
	$value = get_post_meta( $post->ID, '_socrates_plugin_monetize', true );

	// display options
	?>
	<div class="socrates-plugin-post-options-checkbox">

		<input type="checkbox" id="socrates_plugin_monetize" name="_socrates_plugin_monetize" value="hide" <?php if ( $value == 'hide' ) echo 'checked'; ?> />
		<label for="socrates_plugin_monetize"><?php esc_html_e( 'Hide ads', 'socrates-plugin' ); ?></label>

	</div><!-- .socrates-plugin-post-options-checkbox -->
	<?php

}

/**
 * Monetize - Save
 *
 * @since 1.0
 */
function socrates_plugin_ad_meta_box_save( $post_id ) {

	// do not proceed if nonce not set
	if ( ! isset( $_POST['socrates_plugin_monetize_nonce'] ) ) {
		return $post_id;
	}

	// get nonce value
	$nonce = $_POST['socrates_plugin_monetize_nonce'];

	// do not proceed if nonce is wrong
	if ( ! wp_verify_nonce( $nonce, 'socrates_plugin_monetize' ) ) {
		return $post_id;
	}

	// do not proceed if autosave
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return $post_id;
	}

	// do not proceed if user does not have permission
	if ( 'page' == $_POST['post_type'] ) {
		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return $post_id;
		}
	} else {
		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return $post_id;
		}
	}

	// sanitize input
	if ( isset( $_POST['_socrates_plugin_monetize'] ) ) {
		$value = sanitize_text_field( $_POST['_socrates_plugin_monetize'] );	
	} else {
		$value = '';
	}
	// update meta
	if ( $value == '' ) {
		delete_post_meta( $post_id, '_socrates_plugin_monetize' );
	} else {
		update_post_meta( $post_id, '_socrates_plugin_monetize', $value );
	}

} add_action( 'save_post', 'socrates_plugin_ad_meta_box_save' );

/**
 * Other - Display callback
 *
 * @since 1.0
 */
function socrates_plugin_other_meta_box_callback( $post ) {

	// nonces for security
	wp_nonce_field( 'socrates_plugin_other', 'socrates_plugin_other_nonce' );

	// current value
	$hide_from_search = get_post_meta( $post->ID, '_socrates_plugin_hide_from_search', true );
	$members_only = get_post_meta( $post->ID, '_socrates_plugin_members_only', true );

	// display options
	?>
	<div class="socrates-plugin-post-options-checkbox">

		<input type="checkbox" id="socrates_plugin_hide_from_search" name="_socrates_plugin_hide_from_search" value="hide" <?php if ( $hide_from_search == 'hide' ) echo 'checked'; ?> />
		<label for="socrates_plugin_hide_from_search"><?php esc_html_e( 'Hide from search', 'socrates-plugin' ); ?></label>
		<br>
		<input type="checkbox" id="socrates_plugin_members_only" name="_socrates_plugin_members_only" value="yes" <?php if ( $members_only == 'yes' ) echo 'checked'; ?> />
		<label for="socrates_plugin_members_only"><?php esc_html_e( 'Members Only', 'socrates-plugin' ); ?></label>

	</div><!-- .socrates-plugin-post-options-checkbox -->
	<?php

}

/**
 * Other - Save
 *
 * @since 1.0
 */
function socrates_plugin_other_meta_box_save( $post_id ) {

	// do not proceed if nonce not set
	if ( ! isset( $_POST['socrates_plugin_other_nonce'] ) ) {
		return $post_id;
	}

	// get nonce value
	$nonce = $_POST['socrates_plugin_other_nonce'];

	// do not proceed if nonce is wrong
	if ( ! wp_verify_nonce( $nonce, 'socrates_plugin_other' ) ) {
		return $post_id;
	}

	// do not proceed if autosave
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return $post_id;
	}

	// do not proceed if user does not have permission
	if ( 'page' == $_POST['post_type'] ) {
		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return $post_id;
		}
	} else {
		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return $post_id;
		}
	}

	// sanitize input
	if ( isset( $_POST['_socrates_plugin_hide_from_search'] ) ) {
		$hide_from_search = sanitize_text_field( $_POST['_socrates_plugin_hide_from_search'] );	
	} else {
		$hide_from_search = '';
	}

	// sanitize input
	if ( isset( $_POST['_socrates_plugin_members_only'] ) ) {
		$members_only = sanitize_text_field( $_POST['_socrates_plugin_members_only'] );	
	} else {
		$members_only = '';
	}

	// update meta
	if ( $hide_from_search == '' ) {
		delete_post_meta( $post_id, '_socrates_plugin_hide_from_search' );
	} else {
		update_post_meta( $post_id, '_socrates_plugin_hide_from_search', $hide_from_search );
	}

	// update meta
	if ( $members_only == '' ) {
		delete_post_meta( $post_id, '_socrates_plugin_members_only' );
	} else {
		update_post_meta( $post_id, '_socrates_plugin_members_only', $members_only );
	}

} add_action( 'save_post', 'socrates_plugin_other_meta_box_save' );